AbstractData

Trait AbstractData 

pub trait AbstractData {
    // Required methods
    fn spec_type(&self, path: &Path) -> Option<SpecType>;
    fn get(&self, path: &Path, field: &Token) -> Option<Value>;
    fn list(&self, path: &Path) -> Vec<&Token>;
    fn visit_specs(&self) -> Vec<&Path>;
}
Interface for scene description data storage.

Required Methods

fn spec_type(&self, path: &Path) -> Option<SpecType>

Return the type of the spec at path.

fn get(&self, path: &Path, field: &Token) -> Option<Value>

Return the value for the given path and field.

fn list(&self, path: &Path) -> Vec<&Token>

Return the names of all the fields that are set at path.

fn visit_specs(&self) -> Vec<&Path>

Visit every spec in this AbstractData object in arbitrary order.

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors