pub struct Attribute<'a>(/* private fields */);Expand description
Scenegraph object for authoring and retrieving numeric, string, and array valued data, sampled over time, or animated by a spline.
Implementations
Methods from Deref<Target = Object<'a>>
pub fn stage(&self) -> &Stage
pub fn path(&self) -> &Path
pub fn metadata<T: ValueType>(&self, key: &Token) -> Option<T>
Sourcepub fn documentation(&self) -> String
pub fn documentation(&self) -> String
Return this object’s documentation (metadata).
This returns the empty string if no documentation has been set.
Sourcepub fn custom_data(&self) -> Dictionary
pub fn custom_data(&self) -> Dictionary
Return this object’s composed customData dictionary.