Object

Struct Object 

pub struct Object<'a> { /* private fields */ }
Base class for Usd scenegraph objects, providing common API.

The commonality between the three types of scenegraph objects in Usd (usd::Prim, usd::Attribute, usd::Relationship) is that they can all have metadata. Other objects in the API simply are kinds of metadata.

Inheritance hierarchy:

Implementations

Source

impl<'a> Object<'a>

pub fn stage(&self) -> &Stage

pub fn path(&self) -> &Path

pub fn metadata<T: ValueType>(&self, key: &Token) -> Option<T>

pub fn documentation(&self) -> String

Return this object’s documentation (metadata).

This returns the empty string if no documentation has been set.

pub fn custom_data(&self) -> Dictionary

Return this object’s composed customData dictionary.