Prim

Struct Prim 

pub struct Prim<'a>(/* private fields */);
usd::Prim is the sole persistent scenegraph object on a usd::Stage, and is the embodiment of a “Prim” as described in the Universal Scene Description Composition Compendium.

Implementations

Source

impl<'a> Prim<'a>

pub fn specifier(&self) -> Option<Specifier>

pub fn get_attribute<'b>(&'b self, name: &Token) -> Attribute<'b>

pub fn has_attribute(&self, name: &Token) -> bool

pub fn children<'b>(&'b self) -> ChildrenIter<'b>

pub fn type_name(&self) -> Token

Methods from Deref<Target = Object<'a>>

pub fn stage(&self) -> &Stage

pub fn path(&self) -> &Path

pub fn metadata<T: ValueType>(&self, key: &Token) -> Option<T>

pub fn documentation(&self) -> String

Return this object’s documentation (metadata).

This returns the empty string if no documentation has been set.

pub fn custom_data(&self) -> Dictionary

Return this object’s composed customData dictionary.