pub struct Relationship<'a>(/* private fields */);Expand description
A usd::Relationship creates dependencies between scenegraph objects by allowing a prim to target other prims, attributes, or relationships.
Methods from Deref<Target = Object<'a>>
pub fn stage(&self) -> &Stage
pub fn path(&self) -> &Path
pub fn metadata<T: ValueType>(&self, key: &Token) -> Option<T>
Sourcepub fn documentation(&self) -> String
pub fn documentation(&self) -> String
Return this object’s documentation (metadata).
This returns the empty string if no documentation has been set.
Sourcepub fn custom_data(&self) -> Dictionary
pub fn custom_data(&self) -> Dictionary
Return this object’s composed customData dictionary.