pub struct LightAPI<'a>(/* private fields */);Expand description
API schema that imparts the quality of being a light onto a prim.
Implementations
Sourceimpl LightAPI<'_>
impl LightAPI<'_>
pub fn define(stage: &Stage, path: impl Into<Path>) -> LightAPI<'_>
Sourcepub fn intensity_attr(&self) -> Attribute<'_>
pub fn intensity_attr(&self) -> Attribute<'_>
Scales the brightness of the light linearly.
Sourcepub fn exposure_attr(&self) -> Attribute<'_>
pub fn exposure_attr(&self) -> Attribute<'_>
Scales the brightness of the light exponentially as a power of 2 (similar to an F-stop control over exposure). The result is multiplied against the intensity.
Sourcepub fn diffuse_attr(&self) -> Attribute<'_>
pub fn diffuse_attr(&self) -> Attribute<'_>
A multiplier for the effect of this light on the diffuse response of materials. This is a non-physical control.
Sourcepub fn specular_attr(&self) -> Attribute<'_>
pub fn specular_attr(&self) -> Attribute<'_>
A multiplier for the effect of this light on the specular response of materials. This is a non-physical control.
Sourcepub fn normalize_attr(&self) -> Attribute<'_>
pub fn normalize_attr(&self) -> Attribute<'_>
Normalizes the emission such that the power of the light remains constant while altering the size of the light, by dividing the luminance by the world-space surface area of the light.
This makes it easier to independently adjust the brightness and size of the light, by causing the total illumination provided by a light to not vary with the area or angular size of the light.
Sourcepub fn color_attr(&self) -> Attribute<'_>
pub fn color_attr(&self) -> Attribute<'_>
The color of emitted light, in the rendering color space. This color is just multiplied with the emission.
Sourcepub fn enable_color_temperature_attr(&self) -> Attribute<'_>
pub fn enable_color_temperature_attr(&self) -> Attribute<'_>
Enables using colorTemperature.
Sourcepub fn color_temperature_attr(&self) -> Attribute<'_>
pub fn color_temperature_attr(&self) -> Attribute<'_>
Color temperature, in degrees Kelvin, representing the white point. The default is a common white point, D65. Lower values are warmer and higher values are cooler. The valid range is from 1000 to 10000. Only takes effect when enableColorTemperature is set to true.